/* 
 * enPathia
 * Eneso Tecnología de Adaptación, S.L. 
 */

#include <gtk/gtk.h>
#include <glib/gi18n.h>
#include "misc.h"
#include "profile.h"
#include "window.h"
#include "icon.h"

#ifdef __MACH__
static GdkPixbuf*	pixbuf_connected	= NULL;
static GdkPixbuf*	pixbuf_disconnected	= NULL;
#else
static GtkStatusIcon* 	status_icon;
#endif	/* __MACH__ */

static GtkMenu* 		menu_icon;

#ifndef __MACH__
static void
status_icon_popup_menu_cb 	(GtkStatusIcon* icon, guint button, guint activate_time, gpointer data);
#endif	/* __MACH__ */

static void
status_icon_activate_cb 	(GtkStatusIcon *icon, gpointer data);
static void
menuitem_quit_activate_cb 	(GtkStatusIcon *icon, gpointer data);


	void
create_icon (void)
{
	GtkWidget*	menuitem_window;
	GtkWidget*	menuitem_quit;
	GtkWidget*	label_window;

	/* Create the menu */
	menu_icon = GTK_MENU (gtk_menu_new ());

	menuitem_quit	= gtk_menu_item_new_with_label (_("Quit enPathia"));
	gtk_menu_shell_append (GTK_MENU_SHELL (menu_icon), menuitem_quit);
	g_signal_connect (menuitem_quit, 
			"activate", G_CALLBACK (menuitem_quit_activate_cb), NULL);

	if (!disable_main_window)
	{
		menuitem_window	= gtk_menu_item_new_with_label ("");
		label_window = GTK_BIN (menuitem_window)->child;
		gtk_label_set_markup (GTK_LABEL (label_window), _("<b>Show window</b>"));
		gtk_menu_shell_append (GTK_MENU_SHELL (menu_icon), menuitem_window);
		g_signal_connect (menuitem_window,
				"activate", G_CALLBACK (status_icon_activate_cb), NULL);
	}

#ifdef __MACH__
	/* Create the dock menu */
	gchar*	data_file;

	data_file = get_data_file ("/icons/enpathia.ico");
	pixbuf_connected = gdk_pixbuf_new_from_file (data_file, NULL);
	g_free (data_file);

	data_file = get_data_file ("/icons/enpathia_gr.ico");
	pixbuf_disconnected = gdk_pixbuf_new_from_file (data_file, NULL);
	g_free (data_file);

	gtk_osxapplication_set_dock_menu (gtk_osx_app, GTK_MENU_SHELL (menu_icon));
#else
	/* Create the icon */
	status_icon = gtk_status_icon_new ();

	g_signal_connect (GTK_STATUS_ICON (status_icon),
			"activate", G_CALLBACK (status_icon_activate_cb), NULL);
	g_signal_connect (GTK_STATUS_ICON (status_icon), 
			"popup-menu", G_CALLBACK (status_icon_popup_menu_cb), NULL);
#endif	/* __MACH__ */

	change_icon (TRUE);

	gtk_widget_show_all (GTK_WIDGET (menu_icon));
}

	void
destroy_icon (void)
{
#ifdef __MACH__
#else
	gtk_status_icon_set_visible (status_icon, FALSE);

	g_object_unref (G_OBJECT (status_icon));
#endif	/* __MACH__ */
}

	void
change_icon (gboolean connected)
{
#ifdef __MACH__
	gtk_osxapplication_set_dock_icon_pixbuf (gtk_osx_app,
			connected ? pixbuf_connected : pixbuf_disconnected);
#else
	gchar*	icon_file;

	if (connected)
	{
		icon_file = get_data_file ("/icons/enpathia.ico");
		gtk_status_icon_set_from_file (status_icon, icon_file); 
		gtk_status_icon_set_tooltip (status_icon, _("enPathia - Accessible computer control"));
	}
	else
	{
		icon_file = get_data_file ("/icons/enpathia_gr.ico");
		gtk_status_icon_set_from_file (status_icon, icon_file);
		gtk_status_icon_set_tooltip (status_icon, _("enPathia - Accessible computer control (disconnected)"));
	}

	g_free (icon_file);
#endif	/* __MACH__ */
}

#ifndef __MACH__
	static void
status_icon_popup_menu_cb (GtkStatusIcon* icon, guint button, guint activate_time, gpointer data)
{
	gtk_menu_popup (menu_icon, NULL, NULL, NULL, NULL, button, activate_time);
}
#endif	/* __MACH__ */

	static void
status_icon_activate_cb (GtkStatusIcon *icon, gpointer data)
{
	show_main_window (
			current_profile.main_window.x, current_profile.main_window.y);
}

	static void
menuitem_quit_activate_cb (GtkStatusIcon *icon, gpointer data)
{
	quit_with_confirmation ();
}
